# Table of Contents

- [configuring-authentication-to-sap-leanix-apis-in-postman](<./configuring-authentication-to-sap-leanix-apis-in-postman.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Configuring Authentication to SAP LeanIX APIs in Postman](<./Configuring-Authentication-to-SAP-LeanIX-APIs-in-Postman.md>)
  - [Prerequisites](<./Configuring-Authentication-to-SAP-LeanIX-APIs-in-Postman/Prerequisites.md>)
  - [Procedure](<./Configuring-Authentication-to-SAP-LeanIX-APIs-in-Postman/Procedure.md>)
